SentryObservabilityService class
Sentry implementation of ObservabilityService.
This service expects Sentry to be pre-initialized by the
LittlefishObservabilityManager before initialise is called.
It uses the existing Sentry instance via Sentry.clone().
Note: This service uses debugPrint instead of LoggerService because
the logger pipeline routes output back through ObservabilityService via
LoggerObservabilityOutput, which would cause infinite recursion.
- Inheritance
-
- Object
- LittleFishService
- ObservabilityService<
Hub> - SentryObservabilityService
Constructors
Properties
- core ↔ LittleFishCore
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- instance → Hub?
-
no setteroverride
- isReady → bool
-
no setteroverride
- logger → LoggerService
-
no setterinherited
- providerName → String
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings ↔ ObservabilitySettings?
-
getter/setter pairinherited
Methods
-
getAppWrapper(
) → ObservabilityWidgetWrapper? -
Returns a widget wrapper function if the provider supports it.
Used for providers like Sentry that require wrapping the root widget
for features like screenshot capture.
override
-
initialise(
{ObservabilitySettings? settings}) → Future< void> -
override
-
log(
String value, {String level = 'debug'}) → Future< void> -
override
-
logError(
dynamic error, {StackTrace? stackTrace, String reason = '', List< String> tags = const []}) → Future<void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setCustomKey(
String key, Object value) → Future< void> -
override
-
setIsReady(
{required bool isReady}) → Future< void> -
inherited
-
setUserId(
String userId) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited